@@ -190,9 +190,23 @@ def key_events(stdscr, tree1):
         tree1.lofiradio()
 
 def GetSong(link):
-    songfile = str(YouTube("http://youtube.com/" + link.split("/")[-1] ).streams.get_by_itag(251).download())
 
-    AudioSegment.from_file(songfile, "webm").export(str(songfile + ".ogg"), format="ogg")
+    video = YouTube("http://youtube.com/" + link.split("/")[-1] )
+
+    try:
+        video.streams
+    except:
+        return "WRONG LINK ERROR"
+
+    try:
+        songfile = str(video.streams.get_by_itag(251).download(timeout=30))
+    except:
+        return "DOWNLOAD ERROR"
+
+    try:
+        AudioSegment.from_file(songfile, "webm").export(str(songfile + ".ogg"), format="ogg")
+    except:
+        return "CONVERT ERROR"
 
     os.remove(songfile) 
     if os.name == "posix":
@@ -321,7 +335,7 @@ class tree:
     def notify(self, stdscr, maxy, maxx):
         if self.isnotify and time.time() <= self.notifyendtime:
             curses.textpad.rectangle(stdscr, 0,0,2, maxx-1)
-            stdscr.addstr(1,1, self.notifystring[:maxx-3-3] + "...", curses.A_BOLD)
+            stdscr.addstr(1,1, self.notifystring[:maxx-3], curses.A_BOLD)
             self.downloaddisplay = False
 
     def menudisplay(self, stdscr, maxy, maxx):
@@ -539,13 +553,27 @@ class tree:
         self.isnotify = True
         self.notifystring = "Playing: " + str(song).split("/")[-1].split(".webm.ogg")[0]
 
-    def getlofisong(self): # some links dont work, usre recurtion to find a link which works
+    def getlofisong(self): 
+        # some links dont work, usre recurtion to find a link which works
+
         try:
+
             song = GetSong(self.playlist[random.randrange(0, len(self.playlist))])
-        except:
-            if isinternet():
-                song = self.getlofisong()
-            else:
+
+            if song == "WRONG LINK ERROR": # try 3 times to get link, or its a download error, porbably a better way to do this
+                song = GetSong(self.playlist[random.randrange(0, len(self.playlist))])
+                if song == "WRONG LINK ERROR":
+                    song = GetSong(self.playlist[random.randrange(0, len(self.playlist))])
+                    if song == "WRONG LINK ERROR":
+                        song = GetSong(self.playlist[random.randrange(0, len(self.playlist))])
+                        if song == "WRONG LINK ERROR":
+                            song = "DOWNLOAD ERROR"
+
+
+
+
+            if song == "DOWNLOAD ERROR":
+
                 self.isloading = False
 
                 self.notifyendtime = int(time.time()) + 10
@@ -556,9 +584,39 @@ class tree:
                     os.remove(file)
                 for file in list(_ for _ in QOUTE_FOLDER.glob("*.webm")):
                     os.remove(file)
-                exit()
+                return "ERROR"
 
-        return song
+            if song == "CONVERT ERROR":
+
+                self.isloading = False
+
+                self.notifyendtime = int(time.time()) + 10
+                self.isnotify = True
+                self.notifystring = "CONVERT ERROR, IS FFMPEG INSTALLED?"
+                self.radiomode = False
+                for file in list(_ for _ in QOUTE_FOLDER.glob("*.ogg")):
+                    os.remove(file)
+                for file in list(_ for _ in QOUTE_FOLDER.glob("*.webm")):
+                    os.remove(file)
+                return "ERROR"
+          
+
+            return song
+
+        except:
+
+            self.isloading = False
+
+            self.notifyendtime = int(time.time()) + 10
+            self.isnotify = True
+            self.notifystring = "UNABLE TO CONNECT, PLEASE CHECK INTERNET CONNECTION"
+            self.radiomode = False
+            for file in list(_ for _ in QOUTE_FOLDER.glob("*.ogg")):
+                os.remove(file)
+            for file in list(_ for _ in QOUTE_FOLDER.glob("*.webm")):
+                os.remove(file)
+            exit()
+      
 
     def lofiradio(self):
          #lofi playlist from youtube
@@ -573,34 +631,28 @@ class tree:
 
     def actuallofiradio(self):
 
-        try:
 
-            if not hasattr(self, "lofisong"):
-                self.lofisong = self.getlofisong()
-
-            mixer.music.load(self.lofisong)
-            mixer.music.play()
-
-            self.lofisonglen = mixer.Sound(self.lofisong).get_length()
-
-            self.notifyendtime = int(time.time()) + 10
-            self.isnotify = True
-            self.notifystring = "Playing: " + str(self.lofisong).split("/")[-1].split(".webm.ogg")[0]
-
-            os.remove(self.lofisong)
+        if not hasattr(self, "lofisong"):
             self.lofisong = self.getlofisong()
 
-            self.isloading = False
-
-        except:
-            self.isloading = False
-            self.radiomodeo = False
-
-            self.notifyendtime = int(time.time()) + 10
-            self.isnotify = True
-            self.notifystring = "ERROR GETTING AUDIO, PLEASE TRY AGAIN"
+        if self.lofisong == "ERROR":
             exit()
 
+        mixer.music.load(self.lofisong)
+        mixer.music.play()
+
+        self.lofisonglen = mixer.Sound(self.lofisong).get_length()
+
+        self.notifyendtime = int(time.time()) + 10
+        self.isnotify = True
+        self.notifystring = "Playing: " + str(self.lofisong).split("/")[-1].split(".webm.ogg")[0]
+
+        os.remove(self.lofisong)
+        self.lofisong = self.getlofisong()
+
+        self.isloading = False
+
+
 
 
 
